@@ -12,10 +12,11 @@ from csle_common.util.experiment_util import ExperimentUtil
 from csle_common.logging.log import Logger
 from csle_common.metastore.metastore_facade import MetastoreFacade
 from csle_common.dao.jobs.training_job_config import TrainingJobConfig
-from csle_agents.agents.base.base_agent import BaseAgent
-import csle_agents.constants.constants as agents_constants
 from csle_common.dao.training.experiment_execution import ExperimentExecution
 from csle_common.dao.training.tabular_policy import TabularPolicy
+from csle_common.util.general_util import GeneralUtil
+from csle_agents.agents.base.base_agent import BaseAgent
+import csle_agents.constants.constants as agents_constants
 
 
 class PIAgent(BaseAgent):
@@ -70,7 +71,8 @@ class PIAgent(BaseAgent):
                 progress_percentage=0, pid=pid, experiment_result=exp_result,
                 emulation_env_name=None, simulation_traces=[],
                 num_cached_traces=0,
-                log_file_path=Logger.__call__().get_log_file_path(), descr=descr)
+                log_file_path=Logger.__call__().get_log_file_path(), descr=descr,
+                physical_host_ip=GeneralUtil.get_host_ip())
             if self.save_to_metastore:
                 training_job_id = MetastoreFacade.save_training_job(training_job=self.training_job)
                 self.training_job.id = training_job_id
