@@ -18,9 +18,10 @@ from csle_common.logging.log import Logger
 from csle_common.dao.training.fnn_with_softmax_policy import FNNWithSoftmaxPolicy
 from csle_common.metastore.metastore_facade import MetastoreFacade
 from csle_common.dao.jobs.training_job_config import TrainingJobConfig
+from csle_common.models.fnn_w_softmax import FNNwithSoftmax
+from csle_common.util.general_util import GeneralUtil
 from csle_agents.agents.base.base_agent import BaseAgent
 import csle_agents.constants.constants as agents_constants
-from csle_common.models.fnn_w_softmax import FNNwithSoftmax
 
 
 class ReinforceAgent(BaseAgent):
@@ -96,7 +97,8 @@ class ReinforceAgent(BaseAgent):
                 progress_percentage=0, pid=pid, experiment_result=exp_result,
                 emulation_env_name=self.emulation_env_config.name, simulation_traces=[],
                 num_cached_traces=agents_constants.COMMON.NUM_CACHED_SIMULATION_TRACES,
-                log_file_path=Logger.__call__().get_log_file_path(), descr=descr)
+                log_file_path=Logger.__call__().get_log_file_path(), descr=descr,
+                physical_host_ip=GeneralUtil.get_host_ip())
             if self.save_to_metastore:
                 training_job_id = MetastoreFacade.save_training_job(training_job=self.training_job)
                 self.training_job.id = training_job_id
